<!doctype style-sheet PUBLIC "-//James Clark//DTD DSSSL Style Sheet//EN">
<style-specification>
(define %ss-size-factor% 0.6)
(define %ss-shift-factor% 0.4)
(define %smaller-size-factor% 0.9)
(define %bullet-size-factor% 0.8)
(define-unit em 12pt)
;; factor by which to multiply font size for superscripts
(define superscript-size-factor .6)

(define ($ss-seq$ plus-or-minus)
  (make sequence
	font-size:
	  (* (inherited-font-size) %ss-size-factor%)
	position-point-shift:
	  (plus-or-minus (* (inherited-font-size) %ss-shift-factor%))
	(process-children-trim)))

(element (sup) 
  (cond
   ((have-ancestor? "fd") (make superscript (process-children-trim)))
   ((have-ancestor? "f") (make superscript (process-children-trim)))
   (else ($ss-seq$ +)))
)

(element (inf) 
  (cond
   ((have-ancestor? "fd") (make subscript (process-children-trim)))
   ((have-ancestor? "f") (make subscript (process-children-trim)))
   (else ($ss-seq$ -)))
)

;; Font changes
(element rm
  (make sequence
    font-posture: 'upright
    (process-children-trim))) 
(element it
  (make sequence
    font-posture: 'italic
    (process-children-trim))) 
(element b
  (make sequence
    font-weight: 'bold
    (process-children-trim)))
(element tt
  (make sequence
    font-family-name: mono-font-family
    (process-children-trim)))


;; Paragraphs
(define p-style
  (style
    font-family-name: body-font-family
))

(define paragraph-indent 10pt)

(element p
  (make paragraph	
	use: p-style
    space-before: 0pt
    space-after: 0pt
        first-line-start-indent: (if (first-sibling?)
                                 0pt
                                 paragraph-indent)))

(element (caption p) 
   (make sequence   (literal " ")  (process-children-trim)))

(element (abs p) 
  (if (first-sibling?)
     (make sequence   (literal " ") (process-children-trim))
     (make paragraph use: p-style
    space-before: 0pt
    space-after: 0pt
 (process-children-trim)))
)
(element (fn p) 
  (if (first-sibling?)
     (make sequence   (literal " ") (process-children-trim))
     (make paragraph use: p-style
    space-before: 0pt
    space-after: 0pt (process-children-trim)))
)


;; Lists
(define indent-step 20pt)

(element l
  (make sequence
    start-indent: indent-step))

(element li
  (make paragraph
    first-line-start-indent: (- indent-step)
    (make line-field
      field-width: indent-step
      field-align: 'start
      (literal (format-number (child-number)
                              (if (have-ancestor? '("OL" "OL"))
                                  "a"
                                  "1"))))
    (literal ". ")
    (process-children)))

(element qd
  (make paragraph
	space-before: 12pt
        start-indent: (+ (inherited-start-indent)
                     indent-step)
	end-indent: 2pt
	(process-children-trim)))
(element fn 
 (make sequence
  (with-mode footnote (process-matching-children "no"))
   (make page-footnote 
       (with-mode footnote (process-matching-children "no"))
          (process-children-trim)
)))
(mode footnote
 (element (fn no) ($ss-seq$ +)))
(element (fn no) (empty-sosofo))
(element hsp 
   (make line-field 
     field-width: 
       (* 1em (string->number (attribute-string "SP")))
     (literal " "))
)
;(element vsp (make display-space (attribute-string "SP")))
</style-specification>
